Class: YFantasy::PickemTeam::Pick

Inherits:
BaseSubresource show all
Defined in:
lib/y_fantasy/resources/pickem_team/pick.rb

Overview

Represents a single team pick in a pickem fantasy contest

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from BaseSubresource

dependent?, find, resource_name

Methods included from Subresourceable

included

Instance Attribute Details

#lockedBoolean (readonly)

Returns whether the pick is locked and cannot be changed.

Returns:

  • (Boolean)

    whether the pick is locked and cannot be changed



19
# File 'lib/y_fantasy/resources/pickem_team/pick.rb', line 19

option :locked, type: Types::Params::Bool

#resultObject (readonly)

Returns the result of the pick ("correct" or "strike").

Returns:

  • (Object)

    the result of the pick ("correct" or "strike")



15
# File 'lib/y_fantasy/resources/pickem_team/pick.rb', line 15

option :result

#teamString (readonly)

Returns the Yahoo team key (e.g., "nfl.t.1").

Returns:

  • (String)

    the Yahoo team key (e.g., "nfl.t.1")



11
# File 'lib/y_fantasy/resources/pickem_team/pick.rb', line 11

option :team

Instance Method Details

#team_detailsHash

Returns Team details (city, team name, abbreviation) for the pick.

Returns:

  • (Hash)

    Team details (city, team name, abbreviation) for the pick



24
25
26
# File 'lib/y_fantasy/resources/pickem_team/pick.rb', line 24

def team_details
  Ref::Nfl.team(team)
end