Class: YFantasy::Player::OwnershipPercentage

Inherits:
BaseSubresource show all
Defined in:
lib/y_fantasy/resources/player/ownership_percentage.rb

Overview

Represents ownership percentage data for a player in Yahoo Fantasy Sports.

Instance Attribute Summary collapse

Method Summary

Methods inherited from BaseSubresource

dependent?, find, resource_name

Methods included from Subresourceable

included

Instance Attribute Details

#coverage_typeString (readonly)

Returns the type of coverage (e.g., "week").

Returns:

  • (String)

    the type of coverage (e.g., "week")



11
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 11

option :coverage_type

#deltaInteger (readonly)

Returns the change in ownership percentage.

Returns:

  • (Integer)

    the change in ownership percentage



15
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 15

option :delta, type: Types::Coercible::Integer

#valueInteger (readonly)

Returns the ownership percentage, given as a whole number.

Returns:

  • (Integer)

    the ownership percentage, given as a whole number



19
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 19

option :value, type: Types::Coercible::Integer

#weekInteger (readonly)

Returns the week for which ownership percentage is reported.

Returns:

  • (Integer)

    the week for which ownership percentage is reported



23
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 23

option :week, type: Types::Coercible::Integer