Class: YFantasy::Player::OwnershipPercentage
- Inherits:
-
BaseSubresource
- Object
- BaseSubresource
- YFantasy::Player::OwnershipPercentage
- Defined in:
- lib/y_fantasy/resources/player/ownership_percentage.rb
Overview
Represents ownership percentage data for a player in Yahoo Fantasy Sports.
Instance Attribute Summary collapse
-
#coverage_type ⇒ String
readonly
The type of coverage (e.g., "week").
-
#delta ⇒ Integer
readonly
The change in ownership percentage.
-
#value ⇒ Integer
readonly
The ownership percentage, given as a whole number.
-
#week ⇒ Integer
readonly
The week for which ownership percentage is reported.
Method Summary
Methods inherited from BaseSubresource
dependent?, find, resource_name
Methods included from Subresourceable
Instance Attribute Details
#coverage_type ⇒ String (readonly)
Returns the type of coverage (e.g., "week").
11 |
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 11 option :coverage_type |
#delta ⇒ Integer (readonly)
Returns the change in ownership percentage.
15 |
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 15 option :delta, type: Types::Coercible::Integer |
#value ⇒ Integer (readonly)
Returns the ownership percentage, given as a whole number.
19 |
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 19 option :value, type: Types::Coercible::Integer |
#week ⇒ Integer (readonly)
Returns the week for which ownership percentage is reported.
23 |
# File 'lib/y_fantasy/resources/player/ownership_percentage.rb', line 23 option :week, type: Types::Coercible::Integer |